<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 * @package Mosaic
 * @author Wild Web Lab - www.wildweblab.com 
 * @since Mosaic 1.0
 */
 
 
function optionsframework_option_name() {
	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = 'mosaic_theme_options';
	update_option( 'optionsframework', $optionsframework_settings );
}


/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 */
function optionsframework_options() {
	
	$imagepath =  get_template_directory_uri() . '/images/';
	
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'Microsoft YaHei',
		'style' => 'normal',
		'color' => '' 
	);

	
	$options = array();

	$options[] = array(
		'name' => __('General', 'mosaic'),
		'type' => 'heading'
	);
	
	$options['theme_layout'] = array(
		'name' => "排版",
		'desc' => "选择主要版面以及侧边栏的位置。",
		'id' => "theme_layout",
		'std' => "content-sidebar",
		'type' => "images",
		'options' => array(
			'content-sidebar' => $imagepath . '2cr.png',
			'sidebar-content' => $imagepath . '2cl.png',
			'content' => $imagepath . '1col.png',
		)
	);
	
	$options[] = array(
		'name' => __('自定义 Logo', 'mosaic'),
		'desc' => __('上传一个Logo，或者指定Logo文件的URL。', 'mosaic'),
		'id' => 'custom_logo',
		'type' => 'upload'
	);
	
	$options[] = array(
		'name' => __('自定义 Favicon', 'mosaic'),
		'desc' => __('上传一个 16px x 16px 的 Png / Gif / Ico 图像。', 'mosaic'),
		'id' => 'custom_favicon',
		'type' => 'upload'
	);
	
	$options[] = array(
		'name' => __('页码导航风格', 'mosaic'),
		'id' => 'pagination_style',
		'std' => '1',
		'type' => 'select',
		'options' => array(
			'1' => '数字页码',
			'2' => '较旧文章 / 较新文章',
		)
	);
	
	$options[] = array(
		'name' => __('Advanced', 'mosaic'),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __('文章内容', 'mosaic'),
		'id' => 'post_content',
		'std' => '1',
		'type' => 'select',
		'options' => array(
			'1' => 'Full Content',
			'2' => 'The Excerpt',
		)
	);

	$options[] = array(
		'name' => __('在下列哪些地方显示特色图像：', 'mosaic'),
		'desc' => __('', 'mosaic'),
		'id' => 'featured_image',
		'std' => array(),
		'type' => 'multicheck',
		'options' => array(
			'front_page' => '首页',
			'archive_pages' => '存档页',
			'single_posts' => '文章页',
			'search_results' => '搜索结果页',
		)
	);

	$options[] = array(
		'name' => __('特色图像尺寸', 'mosaic'),
		'id' => 'featured_image_size',
		'std' => 'medium',
		'type' => 'select',
		'options' => array(
			'thumbnail' => '缩略图 (150px x 150px)',
			'medium' => '中 (300px x 200px)',
			'large' => '大 (640px x 640px)',
		)
	);

	$options[] = array(
		'name' => __('文章信息', 'mosaic'),
		'desc' => __('博客文章内容下方的数据。', 'mosaic'),
		'id' => 'post_info',
		'std' => '[post_date] by [post_author] [post_comments] [post_edit]',
		'type' => 'text'
	);
	
	$options[] = array(
		'name' => __('文章 Meta', 'mosaic'),
		'desc' => __('每一篇博客文章下方的数据。', 'mosaic'),
		'id' => 'post_meta',
		'std' => '[post_categories before="发表在 " after="."] [post_tags]',
		'type' => 'text'
	);
	
	$options[] = array(
		'name' => __('底部版权信息', 'mosaic'),
		'desc' => __('底部左侧。', 'mosaic'),
		'id' => 'footer_copyright',
		'std' => '[footer_copyright]',
		'type' => 'text'
	);
	
	$options[] = array(
		'name' => __('底部支持信息', 'mosaic'),
		'desc' => __('底部右侧。', 'mosaic'),
		'id' => 'footer_credit',
		'std' => 'Powered by [footer_wordpress_link]. Design by [footer_wildweblab_link]',
		'type' => 'text'
	);
	
	$options[] = array(
		'name' => __('头部脚本', 'mosaic'),
		'desc' => __('键入您想在 wp_head() 里输出的脚本。', 'mosaic'),
		'id' => 'header_scripts',
		'std' => '',
		'type' => 'textarea'
	);
	
	$options[] = array(
		'name' => __('底部脚本', 'mosaic'),
		'desc' => __('键入您想在 wp_footer() 里输出的脚本。 ', 'mosaic'),
		'id' => 'footer_scripts',
		'std' => '',
		'type' => 'textarea'
	);
	
	$options[] = array(
		'name' => __('Styling', 'mosaic'),
		'type' => 'heading'
	);
	
	$options['body_background'] = array(
		'name' =>  __('主体背景', 'mosaic'),
		'desc' => __('自定义主体背景颜色或者选择一个图像。', 'mosaic'),
		'id' => 'body_background',
		'std' => array(
			'color' => '#ffffff'
		),
		'type' => 'background' 
	);
	
	$options['header_background'] = array(
		'name' =>  __('头部背景', 'mosaic'),
		'desc' => __('自定义头部背景颜色或者选择一个图像。', 'mosaic'),
		'id' => 'header_background',
		'std' => array(
			'color' => '#F5F5F5',
			'image' => $imagepath . 'header-footer-bg.png',
			'repeat' => 'repeat',
			'position' => 'top left',
			'attachment' => 'scroll'
		),
		'type' => 'background' 
	);
	
	$options['footer_background'] = array(
		'name' =>  __('底部背景', 'mosaic'),
		'desc' => __('自定义底部背景颜色或者选择一个图像。', 'mosaic'),
		'id' => 'footer_background',
		'std' => array(
			'color' => '#F5F5F5',
			'image' => $imagepath . 'header-footer-bg.png',
			'repeat' => 'repeat',
			'position' => 'top left',
			'attachment' => 'scroll'
		),
		'type' => 'background' 
	);
	
	$options['link_color'] = array(
		'name' => __('链接颜色', 'mosaic'),
		'desc' => __('自定义链接的颜色。', 'mosaic'),
		'id' => 'link_color',
		'std' => '#62A6E4',
		'type' => 'color' 
	);
	
	$options['link_hover_color'] = array(
		'name' => __('链接焦点颜色', 'mosaic'),
		'desc' => __('自定义焦点链接的颜色。', 'mosaic'),
		'id' => 'link_hover_color',
		'std' => '',
		'type' => 'color' 
	);
	
	$options[] = array(
		'name' => __('自定义 CSS', 'mosaic'),
		'desc' => __('增加自定义CSS代码。', 'mosaic'),
		'id' => 'custom_css',
		'std' => 'body {}',
		'type' => 'textarea'
	);
	
	$options[] = array(
		'name' => __('Typography', 'mosaic'),
		'type' => 'heading'
	);
	
	$options['general_font'] = array( 
		'name' => __('通用字体', 'mosaic'),
		'id' => "general_font_typography",
		'std' => array(
			'size' => '15px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#575757' 
		),
		'type' => 'typography' 
	);
	
	$options['site_title'] = array( 
		'name' => __('站点标题', 'mosaic'),
		'id' => "site_title_typography",
		'std' => array(
			'size' => '40px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#696969' 
		),
		'type' => 'typography' 
	);
	
	$options['site_tagline'] = array( 
		'name' => __('站点标语', 'mosaic'),
		'id' => "site_tagline_typography",
		'std' => array(
			'size' => '15px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#949494' 
		),
		'type' => 'typography' 
	);
	
	$options['navigation'] = array( 
		'name' => __('导航栏', 'mosaic'),
		'id' => "navigation_typography",
		'std' => array(
			'size' => '16px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#62A6E4' 
		),
		'type' => 'typography' 
	);
	
	$options['post_title'] = array( 
		'name' => __('文章标题', 'mosaic'),
		'id' => "post_title_typography",
		'std' => array(
			'size' => '30px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#505050' 
		),
		'type' => 'typography' 
	);
	
	$options['post_info'] = array( 
		'name' => __('文章信息', 'mosaic'),
		'id' => "post_info_typography",
		'std' => array(
			'size' => '12px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#8a8888' 
		),
		'type' => 'typography' 
	);
	
	$options['post_meta'] = array( 
		'name' => __('文章 Meta', 'mosaic'),
		'id' => "post_meta_typography",
		'std' => array(
			'size' => '12px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '#8a8888' 
		),
		'type' => 'typography' 
	);
	
	$options['widget_title'] = array( 
		'name' => __('小工具标题', 'mosaic'),
		'id' => "widget_title_typography",
		'std' => array(
			'size' => '18px',
			'face' => 'Microsoft YaHei',
			'style' => 'normal',
			'color' => '' 
		),
		'type' => 'typography' 
	);
	
	
	return $options;
}


add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}

});
</script>

<?php
}